#### My Python Utils. TODO


### IF you dont have time.
```
>>> import pylaxz
>>> help(pylaxz)
```
### ELSE
```
python3 -m pylaxz help
```
1. __logxs__
```
>>> from pylaxz.utils.logxs import *
>>> printf(anything) 
```
2. __check__
```
>>> from pylaxz.utils.check import *
>>> speed()
>>> internet()
>>> ip()
```
2. alternative
```
>>> from pylaxz.utils import check as ck
>>> ck.speed()
>>> ck.internet()
>>> ck.ip()
```
2. is equvalient with 
```
>>> import pylaxz
>>> pylaxz.internet()
``` 
so on
 + printf is logger function and works well with python's data types
 + and also with numpy's data shapes.
